==> bcel-6.4.1-src.tar.gz: bcel-6.4.1-src/src/test/java/org/apache/bcel/util/ClassPathTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.bcel.util;

import java.io.IOException;
import java.io.InputStream;

import org.apache.bcel.AbstractTestCase;
import org.junit.Assert;

public class ClassPathTestCase extends AbstractTestCase {

    public void testGetClassFile() throws IOException {
        Assert.assertNotNull(ClassPath.SYSTEM_CLASS_PATH.getClassFile("java.lang.String"));
    }

    public void testGetResource() throws IOException {
        Assert.assertNotNull(ClassPath.SYSTEM_CLASS_PATH.getResource("java/lang/String.class"));
    }

    public void testGetResourceAsStream() throws IOException {
        try (final InputStream inputStream = ClassPath.SYSTEM_CLASS_PATH
                .getResourceAsStream("java/lang/String.class")) {
            Assert.assertNotNull(inputStream);
        }
    }
}

==> bcel-6.5.0-src.tar.gz: bcel-6.5.0-src/src/test/java/org/apache/bcel/util/ClassPathTestCase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

package org.apache.bcel.util;

import java.io.IOException;
import java.io.InputStream;

import org.apache.bcel.AbstractTestCase;
import org.junit.Assert;

public class ClassPathTestCase extends AbstractTestCase {

    public void testGetClassFile() throws IOException {
        Assert.assertNotNull(ClassPath.SYSTEM_CLASS_PATH.getClassFile("java.lang.String"));
    }

    public void testGetResource() {
        Assert.assertNotNull(ClassPath.SYSTEM_CLASS_PATH.getResource("java/lang/String.class"));
    }

    public void testGetResourceAsStream() throws IOException {
        try (final InputStream inputStream = ClassPath.SYSTEM_CLASS_PATH
                .getResourceAsStream("java/lang/String.class")) {
            Assert.assertNotNull(inputStream);
        }
    }
}
